# !/usr/bin/env python

# This file was originally written by jirihnidek (username on GitHub), here are some links
# regarding the original code:
#
# Author's Website:        https://jirihnidek.github.io/
# Author Gist Page:        https://gist.github.com/jirihnidek
# Source of Original Code: https://gist.github.com/jirihnidek/3f5d36636198e852280f619847d22d9e

"""Aliases for argparse positional arguments."""

import argparse


class SubparserActionAliases(argparse._SubParsersAction) :
    class _AliasedPseudoAction(argparse.Action) :
        
        def __init__(self, name, aliases, help) :
            dest = name
            if aliases :
                dest += ' (%s)' % ','.join(aliases)
            sup = super(SubparserActionAliases._AliasedPseudoAction, self)
            sup.__init__(option_strings=[], dest=dest, help=help)
    
    def add_parser(self, name, **kwargs) :
        if 'aliases' in kwargs :
            aliases = kwargs['aliases']
            del kwargs['aliases']
        else :
            aliases = []
        
        parser = super(SubparserActionAliases, self).add_parser(name, **kwargs)
        
        # Make the aliases work.
        for alias in aliases :
            self._name_parser_map[alias] = parser
        # Make the help text reflect them, first removing old help entry.
        if 'help' in kwargs :
            help = kwargs.pop('help')
            self._choices_actions.pop()
            pseudo_action = self._AliasedPseudoAction(name, aliases, help)
            self._choices_actions.append(pseudo_action)
        
        return parser




# ==============================================================================
#  Copyright (c) Inspyre Softworks 2022.                                       =
#                                                                              =
#  Author:                 T. Blackstone                                       =
#  Author Email:    <t.blackstone@inspyre.tech>                                =
#  Created:              2/10/22, 9:42 PM                                      =
# ==============================================================================

from time import sleep
import random
import sys
import os


def __get_delay(fast=False):
    if fast:
        possible = list(range(45, 100))
    else:
        possible = list(range(100, 301))
    
    delay = random.choice(possible) / 1000
    
    return delay


def clear_console():
    """

    Clear the current terminal screen.

    Returns
    -------
    None.

    """
    cmd = "clear"
    if os.name in ("nt", "dos"):  # Are we running Winblows?
        cmd = "cls"
    
    os.system(cmd)


def animate_typing(
        message: str,
        interval: float = None,
        skip_pre_newline: bool = False,
        skip_post_newline: bool = False,
        clear_screen: bool = False,
        fast_typer: bool = False,
        override_upper_limit: bool = False,
        ):
    """
    
    Animate typing in the terminal/console.
    
    Args:
        message:
        interval:
        skip_pre_newline:
        skip_post_newline:
        clear_screen:
        fast_typer:
        override_upper_limit:

    Returns:

    """
    # If we were instructed to clear the screen, do it.
    if clear_screen:
        clear_console()
    
    # If we weren't instructed to skip a leading newline, print the newline.
    if not skip_pre_newline:
        print("\n")
    
    for char in message:
        if interval is None:
            time_between = __get_delay(fast_typer)
        else:
            time_between = interval
            if time_between >= 0.301:
                time_between = 0.301
            
            if time_between <= 0:
                time_between = __get_delay()
        
        sleep(time_between)
        sys.stdout.write(char)
        
    # If we weren't instructed to skip the post-animation newline, print the newline.
    
    if not skip_post_newline:
        print('\n')



import subprocess
import sys


def up_to_date(name):
    latest_version = str(subprocess.run(
        [sys.executable, '-m', 'pip', 'install', '{}==random'.format(name)], capture_output=True, text=True))
    latest_version = latest_version[latest_version.find('(from versions:')+15:]
    latest_version = latest_version[:latest_version.find(')')]
    latest_version = latest_version.replace(' ', '').split(',')[-1]

    current_version = str(subprocess.run(
        [sys.executable, '-m', 'pip', 'show', '{}'.format(name)], capture_output=True, text=True))
    current_version = current_version[current_version.find('Version:')+8:]
    current_version = current_version[:current_version.find(
        '\\n')].replace(' ', '')

    if latest_version == current_version:
        return True
    else:
        return False




# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['inspyre_toolbox',
 'inspyre_toolbox.console_kit',
 'inspyre_toolbox.core_helpers',
 'inspyre_toolbox.humanize',
 'inspyre_toolbox.humanize.errors',
 'inspyre_toolbox.live_timer',
 'inspyre_toolbox.proc_man',
 'inspyre_toolbox.pypi',
 'inspyre_toolbox.spanners',
 'inspyre_toolbox.syntactic_sweets',
 'inspyre_toolbox.sys_man']

package_data = \
{'': ['*']}

install_requires = \
['DateTime>=4.3,<5.0',
 'inflect>=5.3.0,<6.0.0',
 'insPyred-print>=1.0,<2.0',
 'inspy-logger>=2.1a14,<3.0',
 'jupyter>=1.0.0,<2.0.0',
 'psutil>=5.8.0,<6.0.0',
 'pypattyrn>=1.2,<2.0']

setup_kwargs = {
    'name': 'inspyre-toolbox',
    'version': '1.2',
    'description': 'A toolbox containing some useful tools for Inspyre Softworks packages. Generally useful to some programmers too.',
    'long_description': None,
    'author': 'T Blackstone',
    'author_email': 't.blackstone@inspyre.tech',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
